[master/rhel7 2/2] Change strings per stylistic advice from ECS (#1035898)

David Shea dshea at redhat.com
Tue Aug 5 18:41:13 UTC 2014


Searched and replaced as follows:
  bootloader -> boot loader
  filesystem -> file system
  username -> user name
  [Vv]lan -> VLAN
  hostname -> host name
  ZFCP -> zFCP
  BTRFS -> Btrfs
  can not -> cannot
  mountpoint -> mount point

Also made the capitalization in the iSCSI dialog more consistent and
changed an iSCSI discovery string from past tense to some kind of
perfect tense.
---
 pyanaconda/bootloader.py                        | 48 ++++++++++-----------
 pyanaconda/install.py                           |  2 +-
 pyanaconda/installinterfacebase.py              |  2 +-
 pyanaconda/network.py                           |  2 +-
 pyanaconda/ui/gui/spokes/advstorage/fcoe.glade  |  2 +-
 pyanaconda/ui/gui/spokes/advstorage/iscsi.glade | 16 +++----
 pyanaconda/ui/gui/spokes/custom.glade           | 10 ++---
 pyanaconda/ui/gui/spokes/custom.py              | 56 ++++++++++++-------------
 pyanaconda/ui/gui/spokes/filter.glade           |  2 +-
 pyanaconda/ui/gui/spokes/lib/accordion.py       |  2 +-
 pyanaconda/ui/gui/spokes/lib/cart.py            |  6 +--
 pyanaconda/ui/gui/spokes/lib/dasdfmt.glade      |  2 +-
 pyanaconda/ui/gui/spokes/lib/resize.glade       |  4 +-
 pyanaconda/ui/gui/spokes/lib/resize.py          | 10 ++---
 pyanaconda/ui/gui/spokes/lib/summary.glade      |  2 +-
 pyanaconda/ui/gui/spokes/network.glade          |  8 ++--
 pyanaconda/ui/gui/spokes/network.py             |  2 +-
 pyanaconda/ui/gui/spokes/source.glade           |  8 ++--
 pyanaconda/ui/gui/spokes/storage.glade          |  2 +-
 pyanaconda/ui/gui/spokes/storage.py             |  2 +-
 pyanaconda/ui/gui/spokes/user.glade             |  4 +-
 pyanaconda/ui/gui/spokes/user.py                |  4 +-
 pyanaconda/ui/lib/space.py                      |  4 +-
 pyanaconda/ui/tui/spokes/network.py             |  2 +-
 pyanaconda/ui/tui/spokes/storage.py             |  2 +-
 25 files changed, 102 insertions(+), 102 deletions(-)

diff --git a/pyanaconda/bootloader.py b/pyanaconda/bootloader.py
index 421cdb0..86f87c3 100644
--- a/pyanaconda/bootloader.py
+++ b/pyanaconda/bootloader.py
@@ -243,7 +243,7 @@ class BootLoader(object):
     stage2_mountpoints = ["/boot", "/"]
     stage2_bootable = False
     stage2_must_be_primary = True
-    stage2_description = N_("/boot filesystem")
+    stage2_description = N_("/boot file system")
     stage2_max_end_mb = 2 * 1024 * 1024
 
     @property
@@ -788,7 +788,7 @@ class BootLoader(object):
     @update_only.setter
     def update_only(self, value):
         if value and not self.can_update:
-            raise ValueError("this bootloader does not support updates")
+            raise ValueError("this boot loader does not support updates")
         elif self.can_update:
             self._update_only = value
 
@@ -949,7 +949,7 @@ class BootLoader(object):
     def write_config(self):
         """ Write the bootloader configuration. """
         if not self.config_file:
-            raise BootLoaderError("no config file defined for this bootloader")
+            raise BootLoaderError("no config file defined for this boot loader")
 
         self.add_crash_args()
 
@@ -1318,7 +1318,7 @@ class GRUB(BootLoader):
     def install(self, args=None):
         rc = iutil.execInSysroot("grub-install", ["--just-copy"])
         if rc:
-            raise BootLoaderError("bootloader install failed")
+            raise BootLoaderError("boot loader install failed")
 
         for (stage1dev, stage2dev) in self.install_targets:
             cmd = ("root %(stage2dev)s\n"
@@ -1339,7 +1339,7 @@ class GRUB(BootLoader):
             rc = iutil.execInSysroot("grub", args, stdin=pread)
             os.close(pread)
             if rc:
-                raise BootLoaderError("bootloader install failed")
+                raise BootLoaderError("boot loader install failed")
 
     def update(self):
         self.install()
@@ -1369,14 +1369,14 @@ class GRUB(BootLoader):
                 self.stage2_device.level == mdraid.RAID1 and \
                 self.stage1_device.type != "mdarray":
             if not self.stage1_device.isDisk:
-                msg = _("bootloader stage2 device %(stage2dev)s in on a multi-disk array, but bootloader stage1 device %(stage1dev)s is not. " \
+                msg = _("boot loader stage2 device %(stage2dev)s in on a multi-disk array, but boot loader stage1 device %(stage1dev)s is not. " \
                         "A drive failure in %(stage2dev)s could render the system unbootable.") % \
                         {"stage1dev" : self.stage1_device.name,
                          "stage2dev" : self.stage2_device.name}
                 self.warnings.append(msg)
             elif not self.stage2_device.dependsOn(self.stage1_device):
-                msg = _("bootloader stage2 device %(stage2dev)s is on a multi-disk array, but bootloader stage1 device %(stage1dev)s is not part of this array. " \
-                        "The stage1 bootloader will only be installed to a single drive.") % \
+                msg = _("boot loader stage2 device %(stage2dev)s is on a multi-disk array, but boot loader stage1 device %(stage1dev)s is not part of this array. " \
+                        "The stage1 boot loader will only be installed to a single drive.") % \
                         {"stage1dev" : self.stage1_device.name,
                          "stage2dev" : self.stage2_device.name}
                 self.warnings.append(msg)
@@ -1400,7 +1400,7 @@ class GRUB2(GRUB):
 
         - BIOS boot partition (GPT)
             - parted /dev/sda set <partition_number> bios_grub on
-            - can't contain a filesystem
+            - can't contain a file system
             - 31KiB min, 1MiB recommended
 
     """
@@ -1533,7 +1533,7 @@ class GRUB2(GRUB):
         os.close(pread)
         self.encrypted_password = buf.split()[-1].strip()
         if not self.encrypted_password.startswith("grub.pbkdf2."):
-            raise BootLoaderError("failed to encrypt bootloader password")
+            raise BootLoaderError("failed to encrypt boot loader password")
 
     def write_password_config(self):
         if not self.password and not self.encrypted_password:
@@ -1568,7 +1568,7 @@ class GRUB2(GRUB):
         try:
             self.write_password_config()
         except (BootLoaderError, OSError, RuntimeError) as e:
-            log.error("bootloader password setup failed: %s" % e)
+            log.error("boot loader password setup failed: %s" % e)
 
         # make sure the default entry is the OS we are installing
         entry_title = "%s Linux, with Linux %s" % (productName,
@@ -1581,7 +1581,7 @@ class GRUB2(GRUB):
         rc = iutil.execInSysroot("grub2-mkconfig",
                                  ["-o", self.config_file])
         if rc:
-            raise BootLoaderError("failed to write bootloader configuration")
+            raise BootLoaderError("failed to write boot loader configuration")
 
     #
     # installation
@@ -1603,7 +1603,7 @@ class GRUB2(GRUB):
                                         root=iutil.getSysroot(),
                                         env_prune=['MALLOC_PERTURB_'])
             if rc:
-                raise BootLoaderError("bootloader install failed")
+                raise BootLoaderError("boot loader install failed")
 
     def write(self):
         """ Write the bootloader configuration and install the bootloader. """
@@ -1655,7 +1655,7 @@ class GRUB2(GRUB):
             start = p.geometry.start * p.disk.device.sectorSize
             if not p.getFlag(PARTITION_BIOS_GRUB) and start < min_start:
                 msg = _("%(deviceName)s may not have enough space for grub2 to embed "
-                        "core.img when using the %(fsType)s filesystem on %(deviceType)s") \
+                        "core.img when using the %(fsType)s file system on %(deviceType)s") \
                         % {"deviceName": self.stage1_device.name, "fsType": self.stage2_device.format.type,
                            "deviceType": self.stage2_device.type}
                 log.error(msg)
@@ -1784,7 +1784,7 @@ class MacEFIGRUB(EFIGRUB):
         if os.path.exists(iutil.getSysroot() + "/usr/libexec/mactel-boot-setup"):
             rc = iutil.execInSysroot("/usr/libexec/mactel-boot-setup", [])
             if rc:
-                log.error("failed to configure Mac bootloader")
+                log.error("failed to configure Mac boot loader")
 
     def install(self):
         super(MacEFIGRUB, self).install()
@@ -1918,7 +1918,7 @@ class Yaboot(YabootBase):
         args = ["-f", "-C", self.config_file]
         rc = iutil.execInSysroot(self.prog, args)
         if rc:
-            raise BootLoaderError("bootloader installation failed")
+            raise BootLoaderError("boot loader installation failed")
 
 
 class IPSeriesYaboot(Yaboot):
@@ -2207,7 +2207,7 @@ class UBOOT(BootLoader):
         rc = iutil.execWithRedirect("a-b-c", [], root=iutil.getSysroot())
 
         if rc:
-            raise BootLoaderError("bootloader install failed")
+            raise BootLoaderError("boot loader install failed")
 
 class EXTLINUX(BootLoader):
     name = "EXTLINUX"
@@ -2306,7 +2306,7 @@ class EXTLINUX(BootLoader):
         rc = iutil.execInSysroot("extlinux", args)
 
         if rc:
-            raise BootLoaderError("bootloader install failed")
+            raise BootLoaderError("boot loader install failed")
 
 
 # every platform that wants a bootloader needs to be in this dict
@@ -2327,7 +2327,7 @@ def get_bootloader():
         cls = EXTLINUX
     else:
         cls = bootloader_by_platform.get(platform.platform.__class__, BootLoader)
-    log.info("bootloader %s on %s platform" % (cls.__name__, platform_name))
+    log.info("boot loader %s on %s platform" % (cls.__name__, platform_name))
     return cls()
 
 
@@ -2402,13 +2402,13 @@ def writeBootLoader(storage, payload, instClass, ksdata):
     """
     if not storage.bootloader.skip_bootloader:
         stage1_device = storage.bootloader.stage1_device
-        log.info("bootloader stage1 target device is %s" % stage1_device.name)
+        log.info("boot loader stage1 target device is %s" % stage1_device.name)
         stage2_device = storage.bootloader.stage2_device
-        log.info("bootloader stage2 target device is %s" % stage2_device.name)
+        log.info("boot loader stage2 target device is %s" % stage2_device.name)
 
     if isinstance(payload, RPMOSTreePayload):
         if storage.bootloader.skip_bootloader:
-            log.info("skipping bootloader install per user request")
+            log.info("skipping boot loader install per user request")
             return
         writeBootLoaderFinal(storage, payload, instClass, ksdata)
         return
@@ -2416,7 +2416,7 @@ def writeBootLoader(storage, payload, instClass, ksdata):
     # get a list of installed kernel packages
     kernel_versions = payload.kernelVersionList
     if not kernel_versions:
-        log.warning("no kernel was installed -- bootloader config unchanged")
+        log.warning("no kernel was installed -- boot loader config unchanged")
         return
 
     # all the linux images' labels are based on the default image's
@@ -2439,7 +2439,7 @@ def writeBootLoader(storage, payload, instClass, ksdata):
     writeSysconfigKernel(storage, version)
 
     if storage.bootloader.skip_bootloader:
-        log.info("skipping bootloader install per user request")
+        log.info("skipping boot loader install per user request")
         return
 
     # now add an image for each of the other kernels
diff --git a/pyanaconda/install.py b/pyanaconda/install.py
index b8a6b98..f7b1e5d 100644
--- a/pyanaconda/install.py
+++ b/pyanaconda/install.py
@@ -212,7 +212,7 @@ def doInstall(storage, payload, ksdata, instClass):
 
     # Do bootloader.
     if not flags.flags.dirInstall:
-        with progress_report(_("Installing bootloader")):
+        with progress_report(_("Installing boot loader")):
             writeBootLoader(storage, payload, instClass, ksdata)
 
     with progress_report(_("Performing post-installation setup tasks")):
diff --git a/pyanaconda/installinterfacebase.py b/pyanaconda/installinterfacebase.py
index 8e89ecf..3851440 100644
--- a/pyanaconda/installinterfacebase.py
+++ b/pyanaconda/installinterfacebase.py
@@ -49,7 +49,7 @@ class InstallInterfaceBase(object):
             _("Error Setting Up Repository"),
             _("The following error occurred while setting up the "
               "installation repository:\n\n%(e)s\n\n"
-              "Installation can not continue.")
+              "Installation cannot continue.")
             % {'e': exception},
             type = "custom",
             custom_icon="info",
diff --git a/pyanaconda/network.py b/pyanaconda/network.py
index 263417d..193ee85 100644
--- a/pyanaconda/network.py
+++ b/pyanaconda/network.py
@@ -1293,7 +1293,7 @@ def status_message():
                 elif nm.nm_device_type_is_vlan(devname):
                     parent = nm.nm_device_setting_value(devname, "vlan", "parent")
                     vlanid = nm.nm_device_setting_value(devname, "vlan", "id")
-                    msg = _("Vlan %(interface_name)s (%(parent_device)s, ID %(vlanid)s) connected") \
+                    msg = _("VLAN %(interface_name)s (%(parent_device)s, ID %(vlanid)s) connected") \
                           % {"interface_name": devname, "parent_device": parent, "vlanid": vlanid}
             elif len(nonslaves) > 1:
                 devlist = []
diff --git a/pyanaconda/ui/gui/spokes/advstorage/fcoe.glade b/pyanaconda/ui/gui/spokes/advstorage/fcoe.glade
index a8ad147..d356ff1 100644
--- a/pyanaconda/ui/gui/spokes/advstorage/fcoe.glade
+++ b/pyanaconda/ui/gui/spokes/advstorage/fcoe.glade
@@ -111,7 +111,7 @@
             </child>
             <child>
               <object class="GtkCheckButton" id="autoCheckbox">
-                <property name="label" translatable="yes">Use auto _vlan</property>
+                <property name="label" translatable="yes">Use auto _VLAN</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="receives_default">False</property>
diff --git a/pyanaconda/ui/gui/spokes/advstorage/iscsi.glade b/pyanaconda/ui/gui/spokes/advstorage/iscsi.glade
index 33724ab..1eba625 100644
--- a/pyanaconda/ui/gui/spokes/advstorage/iscsi.glade
+++ b/pyanaconda/ui/gui/spokes/advstorage/iscsi.glade
@@ -258,7 +258,7 @@
                                 <property name="visible">True</property>
                                 <property name="can_focus">False</property>
                                 <property name="xalign">0</property>
-                                <property name="label" translatable="yes">CHAP _Username:</property>
+                                <property name="label" translatable="yes">CHAP _User name:</property>
                                 <property name="use_underline">True</property>
                                 <property name="mnemonic_widget">chapUsernameEntry</property>
                               </object>
@@ -397,7 +397,7 @@
                                 <property name="visible">True</property>
                                 <property name="can_focus">False</property>
                                 <property name="xalign">0</property>
-                                <property name="label" translatable="yes">CHAP _Username:</property>
+                                <property name="label" translatable="yes">CHAP _User name:</property>
                                 <property name="use_underline">True</property>
                                 <property name="mnemonic_widget">rchapUsernameEntry</property>
                               </object>
@@ -429,7 +429,7 @@
                                 <property name="visible">True</property>
                                 <property name="can_focus">False</property>
                                 <property name="xalign">0</property>
-                                <property name="label" translatable="yes">Reverse CHAP User_name:</property>
+                                <property name="label" translatable="yes">Reverse CHAP User _name:</property>
                                 <property name="use_underline">True</property>
                                 <property name="mnemonic_widget">rchapReverseUsername</property>
                               </object>
@@ -680,7 +680,7 @@
                         <property name="visible">True</property>
                         <property name="can_focus">False</property>
                         <property name="xalign">0</property>
-                        <property name="label" translatable="yes">The following nodes were discovered using the iSCSI initiator &lt;b&gt;%(initiatorName)s&lt;/b&gt; using the target IP address &lt;b&gt;%(targetAddress)s&lt;/b&gt;.  Please select which nodes you wish to log into:</property>
+                        <property name="label" translatable="yes">The following nodes have been discovered using the iSCSI initiator &lt;b&gt;%(initiatorName)s&lt;/b&gt; using the target IP address &lt;b&gt;%(targetAddress)s&lt;/b&gt;.  Please select which nodes you wish to log into:</property>
                         <property name="use_markup">True</property>
                         <property name="wrap">True</property>
                       </object>
@@ -762,7 +762,7 @@
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
                             <property name="xalign">0</property>
-                            <property name="label" translatable="yes">_Node login authentication type:</property>
+                            <property name="label" translatable="yes">_Node Login Authentication Type:</property>
                             <property name="use_underline">True</property>
                             <property name="mnemonic_widget">loginAuthTypeCombo</property>
                           </object>
@@ -820,7 +820,7 @@
                                     <property name="visible">True</property>
                                     <property name="can_focus">False</property>
                                     <property name="xalign">0</property>
-                                    <property name="label" translatable="yes">CHAP _Username:</property>
+                                    <property name="label" translatable="yes">CHAP _User name:</property>
                                     <property name="use_underline">True</property>
                                     <property name="mnemonic_widget">loginChapUsernameEntry</property>
                                   </object>
@@ -965,7 +965,7 @@
                                     <property name="visible">True</property>
                                     <property name="can_focus">False</property>
                                     <property name="xalign">0</property>
-                                    <property name="label" translatable="yes">CHAP _Username:</property>
+                                    <property name="label" translatable="yes">CHAP _User name:</property>
                                     <property name="use_underline">True</property>
                                     <property name="mnemonic_widget">loginRchapUsernameEntry</property>
                                   </object>
@@ -997,7 +997,7 @@
                                     <property name="visible">True</property>
                                     <property name="can_focus">False</property>
                                     <property name="xalign">0</property>
-                                    <property name="label" translatable="yes">_Reverse CHAP Username:</property>
+                                    <property name="label" translatable="yes">_Reverse CHAP User name:</property>
                                     <property name="use_underline">True</property>
                                     <property name="mnemonic_widget">loginRchapReverseUsername</property>
                                   </object>
diff --git a/pyanaconda/ui/gui/spokes/custom.glade b/pyanaconda/ui/gui/spokes/custom.glade
index a94aef2..b66d4ac 100644
--- a/pyanaconda/ui/gui/spokes/custom.glade
+++ b/pyanaconda/ui/gui/spokes/custom.glade
@@ -261,7 +261,7 @@ use.  Try something else?</property>
         </child>
         <child>
           <object class="GtkCheckButton" id="removeAllCheckbox">
-            <property name="label" translatable="yes">Delete _all other filesystems in the %s root as well.</property>
+            <property name="label" translatable="yes">Delete _all other file systems in the %s root as well.</property>
             <property name="visible">True</property>
             <property name="can_focus">True</property>
             <property name="receives_default">False</property>
@@ -1056,7 +1056,7 @@ use.  Try something else?</property>
                                         <property name="id_column">1</property>
                                         <items>
                                           <item translatable="yes">Standard Partition</item>
-                                          <item translatable="yes">BTRFS</item>
+                                          <item translatable="yes">Btrfs</item>
                                           <item translatable="yes">LVM</item>
                                           <item translatable="yes">RAID</item>
                                           <item translatable="yes">LVM Thin Provisioning</item>
@@ -1637,7 +1637,7 @@ until you click on the main menu's 'Begin Installation' button.</property>
                             <property name="height_request">36</property>
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
-                            <property name="tooltip_text" translatable="yes">Add a new mountpoint.</property>
+                            <property name="tooltip_text" translatable="yes">Add a new mount point.</property>
                             <property name="label" translatable="yes">addButton</property>
                             <property name="use_underline">True</property>
                             <property name="icon_name">list-add-symbolic</property>
@@ -1654,7 +1654,7 @@ until you click on the main menu's 'Begin Installation' button.</property>
                             <property name="height_request">36</property>
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
-                            <property name="tooltip_text" translatable="yes">Remove the selected mountpoint(s).</property>
+                            <property name="tooltip_text" translatable="yes">Remove the selected mount point(s).</property>
                             <property name="label" translatable="yes">removeButton</property>
                             <property name="use_underline">True</property>
                             <property name="icon_name">list-remove-symbolic</property>
@@ -1671,7 +1671,7 @@ until you click on the main menu's 'Begin Installation' button.</property>
                             <property name="height_request">36</property>
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
-                            <property name="tooltip_text" translatable="yes">Configure selected mountpoint.</property>
+                            <property name="tooltip_text" translatable="yes">Configure selected mount point.</property>
                             <property name="label" translatable="yes">configureButton</property>
                             <property name="use_underline">True</property>
                             <property name="icon_name">preferences-system-symbolic</property>
diff --git a/pyanaconda/ui/gui/spokes/custom.py b/pyanaconda/ui/gui/spokes/custom.py
index 8dd52d4..5456958 100644
--- a/pyanaconda/ui/gui/spokes/custom.py
+++ b/pyanaconda/ui/gui/spokes/custom.py
@@ -111,11 +111,11 @@ unrecoverable_error_msg = N_("Storage configuration reset due to unrecoverable "
 device_configuration_error_msg = N_("Device reconfiguration failed. Click for "
                                     "details.")
 
-label_format_invalid_msg = N_("Unacceptable label format for filesystem.")
-label_application_unavailable_msg = N_("Can not set label on filesystem.")
-label_resetting_forbidden_msg = N_("Can not relabel already existing filesystem.")
+label_format_invalid_msg = N_("Unacceptable label format for file system.")
+label_application_unavailable_msg = N_("Cannot set label on file system.")
+label_resetting_forbidden_msg = N_("Cannot relabel already existing file system.")
 
-empty_mountpoint_msg = N_("Please enter a valid mountpoint.")
+empty_mountpoint_msg = N_("Please enter a valid mount point.")
 invalid_mountpoint_msg = N_("That mount point is invalid. Try something else?")
 mountpoint_in_use_msg = N_("That mount point is already in use. Try something else?")
 
@@ -155,7 +155,7 @@ DEVICE_TEXT_LVM = N_("LVM")
 DEVICE_TEXT_LVM_THINP = N_("LVM Thin Provisioning")
 DEVICE_TEXT_MD = N_("RAID")
 DEVICE_TEXT_PARTITION = N_("Standard Partition")
-DEVICE_TEXT_BTRFS = N_("BTRFS")
+DEVICE_TEXT_BTRFS = N_("Btrfs")
 DEVICE_TEXT_DISK = N_("Disk")
 
 device_text_map = {DEVICE_TYPE_LVM: DEVICE_TEXT_LVM,
@@ -223,7 +223,7 @@ def populate_mountpoint_store(store, used_mountpoints):
 
 def validate_label(label, fmt):
     """Returns a code indicating either that the given label can be set for
-       this filesystem or the reason why it can not.
+       this file system or the reason why it can not.
 
        In the case where the format can not assign a label, the empty string
        stands for accept the default, but in the case where the format can
@@ -1044,7 +1044,7 @@ class CustomPartitioningSpoke(NormalSpoke, StorageChecker):
                      "from GPT-partitioned disks on BIOS hardware.")
         elif name == "PReP Boot":
             return _("The PReP boot partition is required as part of the\n"
-                     "bootloader configuration on some PPC platforms.")
+                     "boot loader configuration on some PPC platforms.")
         else:
             return ""
 
@@ -1255,7 +1255,7 @@ class CustomPartitioningSpoke(NormalSpoke, StorageChecker):
         elif encrypted and new_fs_type in partition_only_format_types:
             error = _("%s cannot be encrypted") % fs_type
         elif mountpoint == "/" and device.format.exists and not reformat:
-            error = _("You must create a new filesystem on the root device.")
+            error = _("You must create a new file system on the root device.")
         elif device_type == DEVICE_TYPE_MD and raid_level in (None, "single"):
             error = _("Devices of type %s require a valid RAID level selection.") % DEVICE_TEXT_MD
 
@@ -1920,7 +1920,7 @@ class CustomPartitioningSpoke(NormalSpoke, StorageChecker):
         if self._sizeEntry.get_sensitive():
             self._sizeEntry.props.has_tooltip = False
         elif device.format.type == "btrfs":
-            self._sizeEntry.set_tooltip_text(_("The space available to this mountpoint can be changed by modifying the volume below."))
+            self._sizeEntry.set_tooltip_text(_("The space available to this mount point can be changed by modifying the volume below."))
         else:
             self._sizeEntry.set_tooltip_text(_("This file system may not be resized."))
 
@@ -3000,47 +3000,47 @@ class CustomPartitioningSpoke(NormalSpoke, StorageChecker):
     def on_value_changed(self, *args):
         self._applyButton.set_sensitive(True)
 
-help_text_template = N_("""You have chosen to manually set up the filesystems for your new %(productName)s installation. Before you begin, you might want to take a minute to learn the lay of the land. Quite a bit has changed.
+help_text_template = N_("""You have chosen to manually set up the file systems for your new %(productName)s installation. Before you begin, you might want to take a minute to learn the lay of the land. Quite a bit has changed.
 
-The most important change is that creation of new filesystems has been streamlined. You no longer have to build complex devices like LVM logical volumes in stages (physical volume, then volume group, then logical volume) -- now you just create a logical volume and we'll handle the legwork of setting up the physical volumes and volume group to contain it. We'll also handle adjusting the volume group as you add, remove, and resize logical volumes so you don't have to worry about the mundane details.
+The most important change is that creation of new file systems has been streamlined. You no longer have to build complex devices like LVM logical volumes in stages (physical volume, then volume group, then logical volume) -- now you just create a logical volume and we'll handle the legwork of setting up the physical volumes and volume group to contain it. We'll also handle adjusting the volume group as you add, remove, and resize logical volumes so you don't have to worry about the mundane details.
 
 
 Screen Layout
 
-The left-hand side of the screen shows the OS installations we were able to find on this computer. The new %(productName)s installation is at the top of the list. You can click on the names of the installations to see what filesystems they contain.
+The left-hand side of the screen shows the OS installations we were able to find on this computer. The new %(productName)s installation is at the top of the list. You can click on the names of the installations to see what file systems they contain.
 
-Below the various installations and mountpoints on the left-hand side there are buttons to add a new filesystem, remove the selected filesystem, or configure the selected filesystem.
+Below the various installations and mount points on the left-hand side there are buttons to add a new file system, remove the selected file system, or configure the selected file system.
 
-The right-hand side of the screen is where you can customize the currently-selected mountpoint.
+The right-hand side of the screen is where you can customize the currently-selected mount point.
 
 On the bottom-left you will see a summary of the disks you have chosen to use for the installation. You can click on the blue text to see more detailed information about your selected disks.
 
 
-How to create a new filesystem on a new device
+How to create a new file system on a new device
 
 1. Click on the + button.
-2. Enter the mountpoint and size. (Hint: Hover the mouse pointer over either of the text entry areas for help.)
-3. Select the new mountpoint under "New %(productName)s Installation" on the left-hand side of the screen and customize it to suit your needs.
+2. Enter the mount point and size. (Hint: Hover the mouse pointer over either of the text entry areas for help.)
+3. Select the new mount point under "New %(productName)s Installation" on the left-hand side of the screen and customize it to suit your needs.
 
 
-How to reformat a device/filesystem that already exists on your disk
+How to reformat a device/file system that already exists on your disk
 
-1. Select the filesystem from the left-hand side of the screen.
-2. Click on the "Customize" expander in the mountpoint customization area on the right-hand side of the screen.
-3. Activate the "Reformat" checkbutton, select a filesystem type and, if applicable, enter a mountpoint above in the "Mountpoint" text entry area.
+1. Select the file system from the left-hand side of the screen.
+2. Click on the "Customize" expander in the mount point customization area on the right-hand side of the screen.
+3. Activate the "Reformat" checkbutton, select a file system type and, if applicable, enter a mount point above in the "Mount point" text entry area.
 4. Click on "Apply changes"
 
 
-How to set a mountpoint for a filesystem that already exists on your disk
+How to set a mount point for a file system that already exists on your disk
 
-1. Select the filesystem from the left-hand side of the screen.
-2. Enter a mountpoint in the "Mountpoint" text entry area in the mountpoint customization area.
+1. Select the file system from the left-hand side of the screen.
+2. Enter a mount point in the "Mount point" text entry area in the mount point customization area.
 3. Click on "Apply changes"
 
 
-How to remove a filesystem that already exists on your disk
+How to remove a file system that already exists on your disk
 
-1. Select the filesystem you wish to remove on the left-hand side of the screen.
+1. Select the file system you wish to remove on the left-hand side of the screen.
 2. Click the - button.
 
 Hint: Removing a device that already exists on your disk from the "New %(productName)s Installation" does not remove it from the disk. It only resets that device to its original state. To remove a device that already exists on your disk, you must select it from under any of the other detected installations (or "Unknown") and hit the - button.
@@ -3048,13 +3048,13 @@ Hint: Removing a device that already exists on your disk from the "New %(product
 
 Tips and hints
 
-You can enter sizes for new filesystems that are greater than the total available free space. The installer will come as close as possible to the size you request.
+You can enter sizes for new file systems that are greater than the total available free space. The installer will come as close as possible to the size you request.
 
 By default, new devices use any/all of your selected disks.
 
 You can change which disks a new device may be allocated from by clicking the configure button (the one with a tools graphic) while that device is selected.
 
-When adding a new mountpoint by clicking the + button, leave the size entry blank to make the new device use all available free space.
+When adding a new mount point by clicking the + button, leave the size entry blank to make the new device use all available free space.
 
 When you remove the last device from a container device like an LVM volume group, we will automatically remove that container device to make room for new devices.
 
diff --git a/pyanaconda/ui/gui/spokes/filter.glade b/pyanaconda/ui/gui/spokes/filter.glade
index b83802a..ff1fd10 100644
--- a/pyanaconda/ui/gui/spokes/filter.glade
+++ b/pyanaconda/ui/gui/spokes/filter.glade
@@ -1625,7 +1625,7 @@
                     <property name="layout_style">end</property>
                     <child>
                       <object class="GtkButton" id="addZFCPButton">
-                        <property name="label" translatable="yes">Add _ZFCP LUN...</property>
+                        <property name="label" translatable="yes">Add _zFCP LUN...</property>
                         <property name="visible">True</property>
                         <property name="can_focus">True</property>
                         <property name="receives_default">True</property>
diff --git a/pyanaconda/ui/gui/spokes/lib/accordion.py b/pyanaconda/ui/gui/spokes/lib/accordion.py
index b5f8993..7206a23 100644
--- a/pyanaconda/ui/gui/spokes/lib/accordion.py
+++ b/pyanaconda/ui/gui/spokes/lib/accordion.py
@@ -317,7 +317,7 @@ class CreateNewPage(Page):
 
         label.set_mnemonic_widget(combo)
         combo.append_text(_("Standard Partition"))
-        combo.append_text(_("BTRFS"))
+        combo.append_text(_("Btrfs"))
         combo.append_text(_("LVM"))
         combo.append_text(_("LVM Thin Provisioning"))
         combo.set_active(2)
diff --git a/pyanaconda/ui/gui/spokes/lib/cart.py b/pyanaconda/ui/gui/spokes/lib/cart.py
index 80f308a..dd5334a 100644
--- a/pyanaconda/ui/gui/spokes/lib/cart.py
+++ b/pyanaconda/ui/gui/spokes/lib/cart.py
@@ -126,9 +126,9 @@ class SelectedDisksDialog(GUIObject):
         free = str(Size(bytes=long(free))).upper()
 
         text = P_("<b>%d disk; %s capacity; %s free space</b> "
-                   "(unpartitioned and in filesystems)",
+                   "(unpartitioned and in file systems)",
                   "<b>%d disks; %s capacity; %s free space</b> "
-                   "(unpartitioned and in filesystems)",
+                   "(unpartitioned and in file systems)",
                   count) % (count, size, free)
         self._summary_label.set_markup(text)
 
@@ -181,7 +181,7 @@ class SelectedDisksDialog(GUIObject):
 
     def _toggle_button_text(self, row):
         if row[IS_BOOT_COL]:
-            self._set_button.set_label(_("_Do not install bootloader"))
+            self._set_button.set_label(_("_Do not install boot loader"))
         else:
             self._set_button.set_label(_("_Set as Boot Device"))
 
diff --git a/pyanaconda/ui/gui/spokes/lib/dasdfmt.glade b/pyanaconda/ui/gui/spokes/lib/dasdfmt.glade
index 581bad8..23e7cc1 100644
--- a/pyanaconda/ui/gui/spokes/lib/dasdfmt.glade
+++ b/pyanaconda/ui/gui/spokes/lib/dasdfmt.glade
@@ -25,7 +25,7 @@
                 <property name="visible">True</property>
                 <property name="can_focus">False</property>
                 <property name="valign">start</property>
-                <property name="label" translatable="yes">The following unformatted DASDs have been detected on your system. You can choose to format them now with dasdfmt or cancel to leave them unformatted. Unformatted DASDs can not be used during installation.</property>
+                <property name="label" translatable="yes">The following unformatted DASDs have been detected on your system. You can choose to format them now with dasdfmt or cancel to leave them unformatted. Unformatted DASDs cannot be used during installation.</property>
                 <property name="wrap">True</property>
                 <attributes>
                   <attribute name="font-desc" value="Cantarell 12"/>
diff --git a/pyanaconda/ui/gui/spokes/lib/resize.glade b/pyanaconda/ui/gui/spokes/lib/resize.glade
index 8a468de..d107583 100644
--- a/pyanaconda/ui/gui/spokes/lib/resize.glade
+++ b/pyanaconda/ui/gui/spokes/lib/resize.glade
@@ -171,7 +171,7 @@
                     </child>
                     <child>
                       <object class="GtkTreeViewColumn" id="fsColumn">
-                        <property name="title" translatable="yes">Filesystem</property>
+                        <property name="title" translatable="yes">File System</property>
                         <child>
                           <object class="GtkCellRendererText" id="fsRenderer"/>
                           <attributes>
@@ -310,7 +310,7 @@
                 <property name="can_focus">False</property>
                 <property name="halign">start</property>
                 <property name="margin_bottom">6</property>
-                <property name="label" translatable="yes">&lt;b&gt;%s disks; %s reclaimable space&lt;/b&gt; (in filesystems)</property>
+                <property name="label" translatable="yes">&lt;b&gt;%s disks; %s reclaimable space&lt;/b&gt; (in file systems)</property>
                 <property name="use_markup">True</property>
               </object>
               <packing>
diff --git a/pyanaconda/ui/gui/spokes/lib/resize.py b/pyanaconda/ui/gui/spokes/lib/resize.py
index 347b5ce..2327c6c 100644
--- a/pyanaconda/ui/gui/spokes/lib/resize.py
+++ b/pyanaconda/ui/gui/spokes/lib/resize.py
@@ -207,13 +207,13 @@ class ResizeDialog(GUIObject):
 
         self._update_labels(totalDisks, totalReclaimableSpace, 0)
 
-        description = _("You can remove existing filesystems you no longer need to free up space "
-                        "for this installation.  Removing a filesystem will permanently delete all "
+        description = _("You can remove existing file systems you no longer need to free up space "
+                        "for this installation.  Removing a file system will permanently delete all "
                         "of the data it contains.")
 
         if canShrinkSomething:
             description += "\n\n"
-            description += _("There is also free space available in pre-existing filesystems.  "
+            description += _("There is also free space available in pre-existing file systems.  "
                              "While it's risky and we recommend you back up your data first, you "
                              "can recover that free disk space and make it available for this "
                              "installation below.")
@@ -223,8 +223,8 @@ class ResizeDialog(GUIObject):
 
     def _update_labels(self, nDisks=None, totalReclaimable=None, selectedReclaimable=None):
         if nDisks is not None and totalReclaimable is not None:
-            text = P_("<b>%s disk; %s reclaimable space</b> (in filesystems)",
-                      "<b>%s disks; %s reclaimable space</b> (in filesystems)",
+            text = P_("<b>%s disk; %s reclaimable space</b> (in file systems)",
+                      "<b>%s disks; %s reclaimable space</b> (in file systems)",
                       nDisks) % (nDisks, size_str(totalReclaimable))
             self._reclaimable_label.set_markup(text)
 
diff --git a/pyanaconda/ui/gui/spokes/lib/summary.glade b/pyanaconda/ui/gui/spokes/lib/summary.glade
index aba4914..3e89e4e 100644
--- a/pyanaconda/ui/gui/spokes/lib/summary.glade
+++ b/pyanaconda/ui/gui/spokes/lib/summary.glade
@@ -169,7 +169,7 @@
                     </child>
                     <child>
                       <object class="GtkTreeViewColumn" id="mountpointColumn">
-                        <property name="title" translatable="yes">Mountpoint</property>
+                        <property name="title" translatable="yes">Mount point</property>
                         <child>
                           <object class="GtkCellRendererText" id="mountpointRenderer"/>
                           <attributes>
diff --git a/pyanaconda/ui/gui/spokes/network.glade b/pyanaconda/ui/gui/spokes/network.glade
index 3632f8c..4eac462 100644
--- a/pyanaconda/ui/gui/spokes/network.glade
+++ b/pyanaconda/ui/gui/spokes/network.glade
@@ -122,7 +122,7 @@
         <col id="1">team</col>
       </row>
       <row>
-        <col id="0" translatable="yes">Vlan</col>
+        <col id="0" translatable="yes">VLAN</col>
         <col id="1">vlan</col>
       </row>
     </data>
@@ -271,7 +271,7 @@ updates available for you.</property>
                     <property name="visible">True</property>
                     <property name="can_focus">False</property>
                     <property name="halign">start</property>
-                    <property name="label" translatable="yes">Please use the live desktop environment's tools for customizing your network configuration.  You can set the hostname here.</property>
+                    <property name="label" translatable="yes">Please use the live desktop environment's tools for customizing your network configuration.  You can set the host name here.</property>
                     <property name="ellipsize">start</property>
                   </object>
                   <packing>
@@ -726,7 +726,7 @@ updates available for you.</property>
                                             <property name="visible">True</property>
                                             <property name="can_focus">False</property>
                                             <property name="xalign">1</property>
-                                            <property name="label" translatable="yes">Vlan ID</property>
+                                            <property name="label" translatable="yes">VLAN ID</property>
                                           </object>
                                           <packing>
                                             <property name="left_attach">0</property>
@@ -1814,7 +1814,7 @@ updates available for you.</property>
                                             <property name="visible">True</property>
                                             <property name="can_focus">False</property>
                                             <property name="xalign">1</property>
-                                            <property name="label" translatable="yes">Username</property>
+                                            <property name="label" translatable="yes">User name</property>
                                           </object>
                                           <packing>
                                             <property name="left_attach">0</property>
diff --git a/pyanaconda/ui/gui/spokes/network.py b/pyanaconda/ui/gui/spokes/network.py
index 665cfcf..de58a75 100644
--- a/pyanaconda/ui/gui/spokes/network.py
+++ b/pyanaconda/ui/gui/spokes/network.py
@@ -302,7 +302,7 @@ class NetworkControlBox(GObject.GObject):
         NetworkManager.DeviceType.ETHERNET: _("Ethernet"),
         NetworkManager.DeviceType.WIFI: _("Wireless"),
         NetworkManager.DeviceType.BOND: _("Bond"),
-        NetworkManager.DeviceType.VLAN: _("Vlan"),
+        NetworkManager.DeviceType.VLAN: _("VLAN"),
         NetworkManager.DeviceType.TEAM: _("Team"),
     }
 
diff --git a/pyanaconda/ui/gui/spokes/source.glade b/pyanaconda/ui/gui/spokes/source.glade
index 16a2e75..2d1602a 100644
--- a/pyanaconda/ui/gui/spokes/source.glade
+++ b/pyanaconda/ui/gui/spokes/source.glade
@@ -390,7 +390,7 @@
                         <property name="visible">True</property>
                         <property name="can_focus">False</property>
                         <property name="xalign">0</property>
-                        <property name="label" translatable="yes">&lt;b&gt;User_name&lt;/b&gt;</property>
+                        <property name="label" translatable="yes">&lt;b&gt;User _name&lt;/b&gt;</property>
                         <property name="use_markup">True</property>
                         <property name="use_underline">True</property>
                         <property name="mnemonic_widget">proxyUsernameEntry</property>
@@ -1145,8 +1145,8 @@
                           <object class="GtkEntry" id="repoProxyUsernameEntry">
                             <property name="visible">True</property>
                             <property name="can_focus">True</property>
-                            <property name="tooltip_markup" translatable="yes">Optional proxy username.</property>
-                            <property name="tooltip_text" translatable="yes">Optional proxy username.</property>
+                            <property name="tooltip_markup" translatable="yes">Optional proxy user name.</property>
+                            <property name="tooltip_text" translatable="yes">Optional proxy user name.</property>
                             <property name="invisible_char">●</property>
                             <property name="invisible_char_set">True</property>
                             <signal name="changed" handler="on_repoProxy_changed" swapped="no"/>
@@ -1260,7 +1260,7 @@
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
                             <property name="xalign">0</property>
-                            <property name="label" translatable="yes">User_name:</property>
+                            <property name="label" translatable="yes">User _Name:</property>
                             <property name="use_underline">True</property>
                             <property name="mnemonic_widget">repoProxyUsernameEntry</property>
                             <attributes>
diff --git a/pyanaconda/ui/gui/spokes/storage.glade b/pyanaconda/ui/gui/spokes/storage.glade
index d80e412..658435d 100644
--- a/pyanaconda/ui/gui/spokes/storage.glade
+++ b/pyanaconda/ui/gui/spokes/storage.glade
@@ -929,7 +929,7 @@
                           <object class="GtkLabel" id="label5">
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
-                            <property name="label" translatable="yes" context="GUI|Storage">_Full disk summary and bootloader...</property>
+                            <property name="label" translatable="yes" context="GUI|Storage">_Full disk summary and boot loader...</property>
                             <property name="use_underline">True</property>
                             <attributes>
                               <attribute name="underline" value="True"/>
diff --git a/pyanaconda/ui/gui/spokes/storage.py b/pyanaconda/ui/gui/spokes/storage.py
index 2870dfc..46cd4d5 100644
--- a/pyanaconda/ui/gui/spokes/storage.py
+++ b/pyanaconda/ui/gui/spokes/storage.py
@@ -741,7 +741,7 @@ class StorageSpoke(NormalSpoke, StorageChecker):
         self.data.bootloader.seen = True
 
         if self.data.bootloader.location == "none":
-            self.set_warning(_("You have chosen to skip bootloader installation.  Your system may not be bootable."))
+            self.set_warning(_("You have chosen to skip boot loader installation.  Your system may not be bootable."))
             self.window.show_all()
         else:
             self.clear_info()
diff --git a/pyanaconda/ui/gui/spokes/user.glade b/pyanaconda/ui/gui/spokes/user.glade
index dfe8efa..21877ed 100644
--- a/pyanaconda/ui/gui/spokes/user.glade
+++ b/pyanaconda/ui/gui/spokes/user.glade
@@ -80,7 +80,7 @@
                         <property name="can_focus">False</property>
                         <property name="xalign">1</property>
                         <property name="xpad">10</property>
-                        <property name="label" translatable="yes">_Username</property>
+                        <property name="label" translatable="yes">_User name</property>
                         <property name="use_underline">True</property>
                         <property name="mnemonic_widget">t_username</property>
                         <attributes>
@@ -200,7 +200,7 @@
                         <property name="visible">True</property>
                         <property name="can_focus">False</property>
                         <property name="xalign">0</property>
-                        <property name="label" translatable="yes">&lt;b&gt;Tip:&lt;/b&gt; Keep your username shorter than 32 characters and do not use spaces.</property>
+                        <property name="label" translatable="yes">&lt;b&gt;Tip:&lt;/b&gt; Keep your user name shorter than 32 characters and do not use spaces.</property>
                         <property name="use_markup">True</property>
                       </object>
                       <packing>
diff --git a/pyanaconda/ui/tui/spokes/network.py b/pyanaconda/ui/tui/spokes/network.py
index 8fc3d63..4b14946 100644
--- a/pyanaconda/ui/tui/spokes/network.py
+++ b/pyanaconda/ui/tui/spokes/network.py
@@ -147,7 +147,7 @@ class NetworkSpoke(EditTUISpoke):
             number = TextWidget("%2d)" % (i + 1))
             return ColumnWidget([(4, [number]), (None, [w])], 1)
 
-        _opts = [_("Set hostname")]
+        _opts = [_("Set host name")]
         for devname in self.supported_devices:
             _opts.append(_("Configure device %s") % devname)
         text = [TextWidget(o) for o in _opts]
diff --git a/pyanaconda/ui/tui/spokes/storage.py b/pyanaconda/ui/tui/spokes/storage.py
index 94f2129..e13141d 100644
--- a/pyanaconda/ui/tui/spokes/storage.py
+++ b/pyanaconda/ui/tui/spokes/storage.py
@@ -279,7 +279,7 @@ class StorageSpoke(NormalTUISpoke):
         # ask user to verify they want to format if zerombr not in ks file
         if not self.data.zerombr.zerombr:
             # prepare our msg strings; copied directly from dasdfmt.glade
-            summary = _("The following unformatted DASDs have been detected on your system. You can choose to format them now with dasdfmt or cancel to leave them unformatted. Unformatted DASDs can not be used during installation.\n\n")
+            summary = _("The following unformatted DASDs have been detected on your system. You can choose to format them now with dasdfmt or cancel to leave them unformatted. Unformatted DASDs cannot be used during installation.\n\n")
 
             warntext = _("Warning: All storage changes made using the installer will be lost when you choose to format.\n\nProceed to run dasdfmt?\n")
 
diff --git a/pyanaconda/ui/gui/spokes/user.py b/pyanaconda/ui/gui/spokes/user.py
index 95cc8b7..a0f003a 100644
--- a/pyanaconda/ui/gui/spokes/user.py
+++ b/pyanaconda/ui/gui/spokes/user.py
@@ -473,11 +473,11 @@ class UserSpoke(FirstbootSpokeMixIn, NormalSpoke):
         # if an invalid username was given, that's the biggest issue
         if username and not USERNAME_VALID.match(username):
             self.clear_info()
-            self.set_warning(_("Invalid username"))
+            self.set_warning(_("Invalid user name"))
             self.username.grab_focus()
             self.window.show_all()
         # Return if:
         # - no user is requested (empty username)
         # - no password is required
         # - password is set by kickstart and password text entry is empty
         # - password is set by dialog and _validatePassword returns True
@@ -473,11 +473,11 @@ class UserSpoke(FirstbootSpokeMixIn, NormalSpoke):
             self.window.show_all()
         # Return if:
-        # - no user is requested (empty username)
+        # - no user is requested (empty user name)
         # - no password is required
         # - password is set by kickstart and password text entry is empty
diff --git a/pyanaconda/ui/lib/space.py b/pyanaconda/ui/lib/space.py
index 83c6134..d9183d2 100644
--- a/pyanaconda/ui/lib/space.py
+++ b/pyanaconda/ui/lib/space.py
@@ -28,12 +28,12 @@ log = logging.getLogger("anaconda")
 
 class FileSystemSpaceChecker(object):
     """This object provides for a way to verify that enough space is available
        on configured filesystems to support the current software selections.
        It is run as part of completeness checking every time a spoke changes,
        therefore moving this step up out of both the storage and software
        spokes.
     """
-    error_template = N_("Not enough space in filesystems for the current "
+    error_template = N_("Not enough space in file systems for the current "
                         "software selection. An additional %s is needed.")
 
     def __init__(self, storage, payload):
@@ -28,12 +28,12 @@ log = logging.getLogger("anaconda")
 class FileSystemSpaceChecker(object):
     """This object provides for a way to verify that enough space is available
-       on configured filesystems to support the current software selections.
+       on configured file systems to support the current software selections.
        It is run as part of completeness checking every time a spoke changes,
        therefore moving this step up out of both the storage and software
-- 
2.0.0



More information about the anaconda-patches mailing list